@@ -82,15 +82,19 @@ class GameNode(object):
         self.comment = ""
         self.variations = []
 
+        self.board_cached = None
+
     def board(self):
         """
         Gets a bitboard with the position of the node.
 
-        Its a copy, so modifying the board will not alter the game.
+        It's a copy, so modifying the board will not alter the game.
         """
-        board = self.parent.board()
-        board.push(self.move)
-        return board
+        if not self.board_cached:
+            self.board_cached = self.parent.board()
+            self.board_cached.push(self.move)
+
+        return copy.deepcopy(self.board_cached)
 
     def san(self):
         """
@@ -191,7 +195,7 @@ class GameNode(object):
         """Removes a variation by move."""
         self.variations.remove(self.variation(move))
 
-    def add_variation(self, move, comment="", starting_comment="", nags=set()):
+    def add_variation(self, move, comment="", starting_comment="", nags=()):
         """Creates a child node with the given attributes."""
         node = GameNode()
         node.move = move
